from matplotlib import pyplot as plt
from matplotlib import dates as mpl_dates
import pandas as pd
from datetime import datetime, timedelta

# ucitavamo podatke iz fajla
data = pd.read_csv("bitcoin_prices.csv")
# podaci koje ucivatavamo su tekst, a mi treba da ih tumacimo kao
# datume, pa izvrsavamo odgovarajucu konverziju
data["Date"] = pd.to_datetime(data["Date"])
# zatim sortiramo sve podatke u mestu po datumima
data.sort_values("Date", inplace=True)

# izvajamo obelezene podatke
dates = data["Date"]
open_price = data["Open"]
high_price = data["High"]
low_price = data["Low"]
close_price = data["Close"]
adj_close_price = data["Adj Close"]
volume = data["Volume"]

# crtamo grafik cena po datumima pri otvaranju berze
plt.plot_date(dates, open_price, label="Open price",
                linestyle="--")
# crtamo grafik najvisih ostvarenih cena po datumima
plt.plot_date(dates, high_price, label="High price",
              linestyle="solid")
# da bi grafik bio citljiv, ukljucujemo automatsko formatiranje 
# prikaza datuma. gcf() metod nam omogucava da izdvojimo trenutno
# aktivni prozor
plt.gcf().autofmt_xdate()

# ukoliko zelimo da primenimo neko drugacije formatiranje datuma
# moramo da koristimo odgovarajuci formater i da definisemo
# formatirajuci string koji zelimo (pogledati u dokumentaciji)
date_format = mpl_dates.DateFormatter("%d. %b %Y")
# na x osu (xaxis) tekuceg crteza (gca()) postavljamo definisani formater
plt.gca().xaxis.set_major_formatter(date_format)

# uobicajena podesavanja
plt.title("Bitcoin prices")
plt.xlabel("Date")
plt.ylabel("Price")
plt.legend()

plt.tight_layout()
# crtamo grafik
plt.show()


